.. modoboa-radicale documentation master file, created by
   sphinx-quickstart on Sun Feb 22 14:29:06 2015.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to modoboa-radicale's documentation!
============================================

This `Modoboa <http://modoboa.org/>`_ extension provides a simple
management frontend for `Radicale <http://radicale.org/>`_, a complete
CalDAV (calendar) and CardDAV (contact) server solution.

Features currently supported are:

* Private calendar creation (available for simple users)
* Rights management for private calendars
* Shared calendar creation by domain (available for domain administrators)
* User and shared calendars display
* Events creation/update/delete/view

Contents:

.. toctree::
   :maxdepth: 2

   setup

